
# known

**known** is a collection of reusable python code. 

Install from any one of the following:

* **Install from GitHub** - Recomended (always up-to-date)
```bash
git clone https://github.com/auto-notify-ps/known.git && python -m pip install ./known
```

* **Install from PyPI** - May be older than one release at most.
```bash
python -m pip install known
```

---
